#!/usr/bin/env bash
set -e
echo "Running $0" >> /home/zuul/overcloud-deploy/overcloud/config-download/overcloud/cephadm/cephadm_command.log
ANSIBLE_LOG_PATH="/home/zuul/overcloud-deploy/overcloud/config-download/overcloud/cephadm/cephadm_command.log" ANSIBLE_HOST_KEY_CHECKING=false ansible-playbook -e ansible_python_interpreter=/usr/bin/python3 -e @/home/zuul/overcloud-deploy/overcloud/config-download/overcloud/cephadm/cephadm-extra-vars-heat.yml -e @/home/zuul/overcloud-deploy/overcloud/config-download/overcloud/cephadm/cephadm-extra-vars-ansible.yml -e @/home/zuul/overcloud-deploy/overcloud/config-download/overcloud/global_vars.yaml -i /home/zuul/overcloud-deploy/overcloud/config-download/overcloud/tripleo-ansible-inventory.yaml /usr/share/ansible/tripleo-playbooks/cephadm.yml
 2>&1
